==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/scambi_proposti.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$nomi[$numero] = $nome;
} # fine for $num1

echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1>
<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td><font size=-1>offerta_di</font></td>
<td>_______offerta_______</td>
<td><font size=-1>offerta_per</font></td>
<td>______richiesta______</td>
<td><font size=-1>__Tempo_rimasto__</font></td>
<td><font size=-1>&nbsp;</font></td></tr>";

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);

for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$id_scambio = $dati_scambio[0];
$utente_offerente = $dati_scambio[1];
$calciatori_offerti = $dati_scambio[2];
$calciatori_offerti = explode(";", $calciatori_offerti);
$num_calciatori_offerti = count($calciatori_offerti);
$soldi_offerti = $dati_scambio[3];
$utente_richiesto = $dati_scambio[4];
$calciatori_richiesti = $dati_scambio[5];
$calciatori_richiesti = explode(";", $calciatori_richiesti);
$num_calciatori_richiesti = count($calciatori_richiesti);
$soldi_richiesti = $dati_scambio[6];
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;

if ($sec_restanti > 0) {
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";

for ($num2 = 0 ; $num2 < $num_calciatori_offerti ; $num2++) {
$numero = $calciatori_offerti[$num2];
$nome = $nomi[$numero];
if ($nome == "") $nome = "???";
if ($num2 == 0) $offerta = $nome;
else $offerta .= ", ".$nome;
} # fine for $num2
if ($soldi_offerti != 0) $offerta .= ", ".$soldi_offerti." Fanta-Euro";
for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
$numero = $calciatori_richiesti[$num2];
$nome = $nomi[$numero];
if ($nome == "") $nome = "???";
if ($num2 == 0) $richiesta = $nome;
else $richiesta .= ", ".$nome;
} # fine for $num2
if ($soldi_richiesti != 0) $richiesta .= ", ".$soldi_richiesti." Fanta-Euro";

if ($utente_richiesto == $nome_utente) $accetta = "<a href=\"scambio_accetta.php?id_scambio=$id_scambio&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">accetta</a>";
else $accetta = "&nbsp;";

echo "<tr><td><font size=-1>$utente_offerente</font></td>
<td><font size=-1>$offerta</font></td>
<td><font size=-1>$utente_richiesto</font></td>
<td><font size=-1>$richiesta</font></td>
<td><font size=-1>$tempo_restante</font></td>
<td><font size=-1>$accetta</font></td></tr>";
} # fine if ($sec_restanti > 0)

} # fine for $num1

echo "</table></font>";

echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.4.tar.gz: fantacalciobazar/scambi_proposti.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$nomi[$numero] = $nome;
} # fine for $num1

echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1>
<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td><font size=-1>offerta_di</font></td>
<td>_______offerta_______</td>
<td><font size=-1>offerta_per</font></td>
<td>______richiesta______</td>
<td><font size=-1>__Tempo_rimasto__</font></td>
<td><font size=-1>&nbsp;</font></td></tr>";

$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);

for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$id_scambio = $dati_scambio[0];
$utente_offerente = $dati_scambio[1];
$calciatori_offerti = $dati_scambio[2];
$calciatori_offerti = explode(";", $calciatori_offerti);
$num_calciatori_offerti = count($calciatori_offerti);
$soldi_offerti = $dati_scambio[3];
$utente_richiesto = $dati_scambio[4];
$calciatori_richiesti = $dati_scambio[5];
$calciatori_richiesti = explode(";", $calciatori_richiesti);
$num_calciatori_richiesti = count($calciatori_richiesti);
$soldi_richiesti = $dati_scambio[6];
$tempo_off = $dati_scambio[7];
$tempo_off = togli_acapo($tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;

if ($sec_restanti > 0) {
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";

for ($num2 = 0 ; $num2 < $num_calciatori_offerti ; $num2++) {
$numero = $calciatori_offerti[$num2];
$nome = $nomi[$numero];
if ($nome == "") $nome = "???";
if ($num2 == 0) $offerta = $nome;
else $offerta .= ", ".$nome;
} # fine for $num2
if ($soldi_offerti != 0) $offerta .= ", ".$soldi_offerti." Fanta-Euro";
for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
$numero = $calciatori_richiesti[$num2];
$nome = $nomi[$numero];
if ($nome == "") $nome = "???";
if ($num2 == 0) $richiesta = $nome;
else $richiesta .= ", ".$nome;
} # fine for $num2
if ($soldi_richiesti != 0) $richiesta .= ", ".$soldi_richiesti." Fanta-Euro";

if ($utente_richiesto == $nome_utente) $accetta = "<a href=\"scambio_accetta.php?id_scambio=$id_scambio&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">accetta</a>";
else $accetta = "&nbsp;";

echo "<tr><td><font size=-1>$utente_offerente</font></td>
<td><font size=-1>$offerta</font></td>
<td><font size=-1>$utente_richiesto</font></td>
<td><font size=-1>$richiesta</font></td>
<td><font size=-1>$tempo_restante</font></td>
<td><font size=-1>$accetta</font></td></tr>";
} # fine if ($sec_restanti > 0)

} # fine for $num1

echo "</table></font>";

echo "<br><br><center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
